==> open-xchange-core_7.8.3.orig.tar.bz2: open-xchange-core-7.8.3/com.openexchange.net.ssl.config/src/com/openexchange/net/ssl/config/TrustLevel.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.net.ssl.config;

/**
 * {@link TrustLevel}
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since v7.8.3
 */
public enum TrustLevel {

    TRUST_ALL("all"),

    TRUST_RESTRICTED("restricted");

    private final String level;

    private TrustLevel(String level) {
        this.level = level;
    }

    public String level() {
        return level;
    }

    public static TrustLevel find(String abbr) {
        for (TrustLevel v : values()) {
            if (v.level().equals(abbr)) {
                return v;
            }
        }
        org.slf4j.LoggerFactory.getLogger(TrustLevel.class).error("The defined log level '{}' is invalid. Please use '{}' or '{}'. Will fall back to default: trust 'all'.", abbr, TRUST_ALL.level, TRUST_RESTRICTED.level);
        return TrustLevel.TRUST_ALL;
    }
}

==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.net.ssl.config/src/com/openexchange/net/ssl/config/TrustLevel.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.net.ssl.config;

/**
 * {@link TrustLevel}
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since v7.8.3
 */
public enum TrustLevel {

    /**
     * The "trust-all" trust level
     */
    TRUST_ALL("all"),
    /**
     * The restricted trust level taking configuration (custom trust-store, enabled protocols/cipher suites, etc.) into consideration.
     */
    TRUST_RESTRICTED("restricted");

    private final String level;

    private TrustLevel(String level) {
        this.level = level;
    }

    /**
     * Gets the identifier for this trust level
     *
     * @return The level identifier
     */
    public String level() {
        return level;
    }

    /**
     * Looks up the appropriate trust level for given identifier.
     *
     * @param abbr The identifier to look-up
     * @return The matching trust level or {@link #TRUST_ALL}
     */
    public static TrustLevel find(String abbr) {
        if (null == abbr) {
            org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(TrustLevel.class);
            logger.error("The defined log level '{}' is invalid. Please use '{}' or '{}'. Will fall back to default: trust '{}'.", abbr, TRUST_ALL.level, TRUST_RESTRICTED.level, TRUST_ALL.level);
            return TrustLevel.TRUST_ALL;
        }

        for (TrustLevel v : values()) {
            if (v.level().equals(abbr)) {
                return v;
            }
        }
        org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(TrustLevel.class);
        logger.error("The defined log level '{}' is invalid. Please use '{}' or '{}'. Will fall back to default: trust '{}'.", abbr, TRUST_ALL.level, TRUST_RESTRICTED.level, TRUST_ALL.level);
        return TrustLevel.TRUST_ALL;
    }
}
